[Mpuls-commits] r5013 - in base/trunk: . mpulsweb/controllers mpulsweb/i18n mpulsweb/i18n/de/LC_MESSAGES mpulsweb/model

scm-commit@wald.intevation.org scm-commit at wald.intevation.org
Fri May 27 12:40:31 CEST 2011


Author: torsten
Date: 2011-05-27 12:40:28 +0200 (Fri, 27 May 2011)
New Revision: 5013

Modified:
   base/trunk/ChangeLog
   base/trunk/mpulsweb/controllers/privacy.py
   base/trunk/mpulsweb/i18n/de/LC_MESSAGES/mpulsweb.po
   base/trunk/mpulsweb/i18n/mpulsweb.pot
   base/trunk/mpulsweb/model/case.py
   base/trunk/mpulsweb/model/phase.py
Log:
Issue999: Show different dialogs dependig on the reasion why the anonymisation
fails in case of declining the descretion statement. Changed error texts


Modified: base/trunk/ChangeLog
===================================================================
--- base/trunk/ChangeLog	2011-05-27 08:52:38 UTC (rev 5012)
+++ base/trunk/ChangeLog	2011-05-27 10:40:28 UTC (rev 5013)
@@ -1,3 +1,17 @@
+2011-05-27  Torsten Irländer <torsten.irlaender at intevation.de>
+
+	* mpulsweb/templates/casemanagement/digest.mako: Issue1913: Added ID of case to
+	the digest. Fixed update.
+
+2011-05-26  Torsten Irländer <torsten.irlaender at intevation.de>
+
+	* mpulsweb/model/phase.py: Added new Exception which can be used for
+	checks if cases in a certain phase can be anonymized.
+	* mpulsweb/model/case.py: Raise different exception id anonymisation
+	is not allowed in the current phase.
+	* mpulsweb/controllers/privacy.py: Depending on the Exception return a
+	differen error dialog.
+
 2011-05-27  Ludwig Reiter <ludwig.reiter at inteation.de>
 
 	* mpulsweb/model/case.py,

Modified: base/trunk/mpulsweb/controllers/privacy.py
===================================================================
--- base/trunk/mpulsweb/controllers/privacy.py	2011-05-27 08:52:38 UTC (rev 5012)
+++ base/trunk/mpulsweb/controllers/privacy.py	2011-05-27 10:40:28 UTC (rev 5013)
@@ -11,7 +11,7 @@
 from mpulsweb.lib.security import checkRole
 from mpulsweb.lib.base import BaseController, render, c, h, session
 from mpulsweb.lib.anonymize import determineAnonymizedCaseEndPhase
-from mpulsweb.model.phase import ConsistenceCheckException
+from mpulsweb.model.phase import ConsistenceCheckException, PhaseAnonymizableCheckException
 
 from mpulsweb.controllers.case import \
      MARKANONYMIZE_SUCCESS, MARKANONYMIZE_SUCCESS_TEXT, MARKANONYMIZE_FAILED, \
@@ -29,8 +29,10 @@
 
 PRIVACY_DECLINE_DISALLOWED = _('Decline privacy statement not possible')
 
-PRIVACY_DECLINE_DISALLOWED_TEXT = _('The case is in a non consistent state und it will not be possible to anonimise it after retracting the privacy statement. The reason for this is listed below:<p>%s</p>')
+PRIVACY_DECLINE_DISALLOWED_TEXT = _('<p>The case is in a non consistent state und it will not be possible to anonimise it after retracting the privacy statement. The reason for this is listed below:</p><p>%s</p><p>Please refer to the documentation in case that the privacy statement has been declined.</p>')
 
+PRIVACY_DECLINE_DISALLOWED_TEXT2 = _('The case is in a non consistent state und it will not be possible to anonimise it after retracting the privacy statement. The reason for this is listed below:%s')
+
 PRIVACY_DECLINE = _(u"Retract privacy statement?")
 PRIVACY_DECLINE_TEXT = _(u"The case will be anonymised if you retract the privacy statement.""")
 
@@ -103,6 +105,13 @@
         case = self._loadCase(id)
         try:
             case.check_anonymizeability()
+        except PhaseAnonymizableCheckException, e:
+            c.dialog_title = PRIVACY_DECLINE_DISALLOWED
+            c.dialog_text = h.literal(PRIVACY_DECLINE_DISALLOWED_TEXT2 % e.value)
+            c.url_ok = h.url_for(controller='/case', action='digest',
+                                 id=case.id)
+            return render('/casemanagement/dialogs/failed_markanonymize.mako')
+
         except ConsistenceCheckException, e:
             c.dialog_title = PRIVACY_DECLINE_DISALLOWED
             c.dialog_text = h.literal(PRIVACY_DECLINE_DISALLOWED_TEXT % e.value)

Modified: base/trunk/mpulsweb/i18n/de/LC_MESSAGES/mpulsweb.po
===================================================================
--- base/trunk/mpulsweb/i18n/de/LC_MESSAGES/mpulsweb.po	2011-05-27 08:52:38 UTC (rev 5012)
+++ base/trunk/mpulsweb/i18n/de/LC_MESSAGES/mpulsweb.po	2011-05-27 10:40:28 UTC (rev 5013)
@@ -8,7 +8,7 @@
 "Project-Id-Version: mpulsweb 0.0.0\n"
 "Report-Msgid-Bugs-To: EMAIL at ADDRESS\n"
 "POT-Creation-Date: 2009-10-08 09:54+0200\n"
-"PO-Revision-Date: 2011-05-24 11:06+0200\n"
+"PO-Revision-Date: 2011-05-27 12:33+0200\n"
 "Last-Translator: Torsten Irländer <torsten.irlaender at intevation.de>\n"
 "Language-Team: de <LL at li.org>\n"
 "Plural-Forms: nplurals=2; plural=(n != 1)\n"
@@ -341,8 +341,8 @@
 "Administration zur endgültigen Anonymisierung vor. Bitte klicken Sie auf "
 "\"OK\", um zur Fallaktenübersicht fortzufahren."
 
-#: mpulsweb/controllers/case.py:57 mpulsweb/controllers/case_bundle.py:290
-#: mpulsweb/controllers/case_bundle.py:321
+#: mpulsweb/controllers/case.py:57 mpulsweb/controllers/case_bundle.py:292
+#: mpulsweb/controllers/case_bundle.py:323
 #: mpulsweb/templates/casemanagement/dialogs/confirm.mako:6
 #: mpulsweb/templates/casemanagement/dialogs/confirm_delete.mako:6
 msgid "Delete case?"
@@ -350,7 +350,7 @@
 msgstr[0] "Fallakte löschen?"
 msgstr[1] "Fallakten löschen?"
 
-#: mpulsweb/controllers/case.py:58
+#: mpulsweb/controllers/case.py:58 mpulsweb/controllers/case_bundle.py:330
 msgid ""
 "Warning! On deleting the case all data will be erased\n"
 "irrecoverable!<br>Only delete the case if this case is <b>not needed for\n"
@@ -389,7 +389,7 @@
 msgid "Click on OK to continue."
 msgstr "Bitte klicken Sie \"OK\", um fortzufahren."
 
-#: mpulsweb/controllers/case.py:73 mpulsweb/controllers/case_bundle.py:435
+#: mpulsweb/controllers/case.py:73 mpulsweb/controllers/case_bundle.py:442
 #: mpulsweb/templates/casemanagement/dialogs/confirm_restore.mako:6
 msgid "Restore case?"
 msgid_plural "Restore cases?"
@@ -428,22 +428,22 @@
 "Bei dem Import ist ein Fehler aufgetreten. Klicken Sie auf \"OK\", um zu "
 "dem Importdialog zurückzukehren."
 
-#: mpulsweb/controllers/case.py:218 mpulsweb/model/case.py:1362
-#: mpulsweb/model/phase.py:299
+#: mpulsweb/controllers/case.py:218 mpulsweb/model/case.py:1361
+#: mpulsweb/model/phase.py:304
 #: mpulsweb/templates/casemanagement/caselist.mako:152
 #: mpulsweb/templates/phase/phase.mako:51
 msgid "Running"
 msgstr "laufend"
 
-#: mpulsweb/controllers/case.py:220 mpulsweb/model/case.py:1364
-#: mpulsweb/model/phase.py:301
+#: mpulsweb/controllers/case.py:220 mpulsweb/model/case.py:1363
+#: mpulsweb/model/phase.py:306
 #: mpulsweb/templates/casemanagement/caselist.mako:155
 #: mpulsweb/templates/phase/phase.mako:53
 #: mpulsweb/templates/phase/phase.mako:55
 msgid "Finished"
 msgstr "beendet"
 
-#: mpulsweb/controllers/case.py:272 mpulsweb/controllers/case_bundle.py:425
+#: mpulsweb/controllers/case.py:272 mpulsweb/controllers/case_bundle.py:432
 msgid "Case restored!"
 msgid_plural "Cases restored!"
 msgstr[0] "Fallakte wiederhergestellt!"
@@ -528,13 +528,13 @@
 "Fallakten in einem Zustand befinden, aus dem Sie die Aktion ausführen "
 "können."
 
-#: mpulsweb/controllers/case_bundle.py:200
+#: mpulsweb/controllers/case_bundle.py:202
 msgid "Case was marked for evaluation"
 msgid_plural "Cases were marked for evaluation"
 msgstr[0] "Fallakte wurde für die Auswertung markiert."
 msgstr[1] "Fallakten wurden für die Auswertung markiert."
 
-#: mpulsweb/controllers/case_bundle.py:204
+#: mpulsweb/controllers/case_bundle.py:206
 #, python-format
 msgid ""
 "%d case was marked for evaluation. All following evaluations will be "
@@ -551,47 +551,47 @@
 "Auswertungen werden auf diese Fallakten beschränkt. Bitte klicken sie auf"
 " OK um fortzufahren."
 
-#: mpulsweb/controllers/case_bundle.py:278
+#: mpulsweb/controllers/case_bundle.py:280
 msgid "Case deleted!"
 msgid_plural "Cases deleted!"
 msgstr[0] "Fallakte gelöscht!"
 msgstr[1] "Fallakten gelöscht!"
 
-#: mpulsweb/controllers/case_bundle.py:279
+#: mpulsweb/controllers/case_bundle.py:281
 #, python-format
 msgid "%s case was successfully cleared for deletion."
 msgid_plural "%s cases were successfully cleared for deletion."
 msgstr[0] "Es wurde %s Fallakte erfolgreich zum Löschen freigegeben."
 msgstr[1] "Es wurden %s Fallakten erfolgreich zum Löschen freigegeben."
 
-#: mpulsweb/controllers/case_bundle.py:295
-#: mpulsweb/controllers/case_bundle.py:326
+#: mpulsweb/controllers/case_bundle.py:297
+#: mpulsweb/controllers/case_bundle.py:328
 #, python-format
 msgid "Do you really want to delete the following case?%s"
 msgid_plural "Do you really want to delete the following cases?%s"
 msgstr[0] "Wollen Sie wirklich die folgende Fallakte löschen?%s"
 msgstr[1] "Wollen Sie wirklich die folgenden Fallakten löschen?%s"
 
-#: mpulsweb/controllers/case_bundle.py:309
+#: mpulsweb/controllers/case_bundle.py:311
 msgid "Case successfully deleted."
 msgid_plural "Cases successfully deleted."
 msgstr[0] "Akte gelöscht!"
 msgstr[1] "Akten gelöscht!"
 
-#: mpulsweb/controllers/case_bundle.py:312
+#: mpulsweb/controllers/case_bundle.py:314
 #, python-format
 msgid "%s case was successfully deleted."
 msgid_plural "%s cases were successfully deleted."
 msgstr[0] "Es wurde %s Akte gelöscht."
 msgstr[1] "Es wurden %s Akten gelöscht."
 
-#: mpulsweb/controllers/case_bundle.py:341
+#: mpulsweb/controllers/case_bundle.py:348
 msgid "Case successfully cleared for anonymisation!"
 msgid_plural "Cases successfully cleared for anonymisation!"
 msgstr[0] "Fallakte wurde zur Anonymisierung freigegeben!"
 msgstr[1] "Fallakten wurden zur Anonymisierung freigegeben!"
 
-#: mpulsweb/controllers/case_bundle.py:347
+#: mpulsweb/controllers/case_bundle.py:354
 #, python-format
 msgid ""
 "%s case was cleared for anonymisation. It will be presented to the "
@@ -606,13 +606,13 @@
 "Es wurden %s Fallakten zur Anonymisierung freigegeben. Sie liegen der "
 "Administration zur endgültigen Anonymisierung vor."
 
-#: mpulsweb/controllers/case_bundle.py:360
+#: mpulsweb/controllers/case_bundle.py:367
 msgid "Clear case for anonymisation?"
 msgid_plural "Clear cases for anonymisation?"
 msgstr[0] "Fallakte zur Anonymisierung freigeben?"
 msgstr[1] "Fallakten zur Anonymisierung freigeben?"
 
-#: mpulsweb/controllers/case_bundle.py:372
+#: mpulsweb/controllers/case_bundle.py:379
 #, python-format
 msgid ""
 "Do you really want to clear the following case for anonymisation? The "
@@ -632,26 +632,26 @@
 "Die Fallakten stehen Ihnen danach nicht mehr zur Bearbeitung zur "
 "Verfügung und werden der Administration zur Anonymisierung vorgelegt.%s"
 
-#: mpulsweb/controllers/case_bundle.py:386
+#: mpulsweb/controllers/case_bundle.py:393
 msgid "Case anonymised!"
 msgid_plural "Cases anonymised!"
 msgstr[0] "Fallakte anonymisiert!"
 msgstr[1] "Fallakten anonymisiert!"
 
-#: mpulsweb/controllers/case_bundle.py:389
+#: mpulsweb/controllers/case_bundle.py:396
 #, python-format
 msgid "%s case was successfully anonymised."
 msgid_plural "%s cases were successfully anonymised."
 msgstr[0] "Es wurde %s Akte anonymisiert."
 msgstr[1] "Es wurden %s Akten anonymisiert."
 
-#: mpulsweb/controllers/case_bundle.py:398
+#: mpulsweb/controllers/case_bundle.py:405
 msgid "Anonymise case?"
 msgid_plural "Anonymise cases?"
 msgstr[0] "Fallakte anonymisieren?"
 msgstr[1] "Fallakten anonymisieren?"
 
-#: mpulsweb/controllers/case_bundle.py:410
+#: mpulsweb/controllers/case_bundle.py:417
 #, python-format
 msgid ""
 "Do you really want to anonymise the case and irrevocably lose its "
@@ -672,14 +672,14 @@
 "mehr zur Bearbeitung zur Verfügung. Die anonymisierten Fallakten werden "
 "weiterhin in der Auswertung berücksichtigt werden.%s"
 
-#: mpulsweb/controllers/case_bundle.py:427
+#: mpulsweb/controllers/case_bundle.py:434
 #, python-format
 msgid "%s was successfully restored."
 msgid_plural "%s were successfully restored."
 msgstr[0] "Es wurde %s Fallakte erfolgreich wiederhergestellt."
 msgstr[1] "Es wurden %s Fallakten erfolgreich wiederhergestellt."
 
-#: mpulsweb/controllers/case_bundle.py:441
+#: mpulsweb/controllers/case_bundle.py:448
 #, python-format
 msgid ""
 "Do you really want to restore the following case? It will be available "
@@ -694,47 +694,47 @@
 "Wollen Sie wirklich die folgenden Fallakten wiederherstellen? Die "
 "Fallakten stehen danach wieder zur Bearbeitung zur Verfügung. %s"
 
-#: mpulsweb/controllers/case_bundle.py:458
+#: mpulsweb/controllers/case_bundle.py:465
 msgid "Editor appointed!"
 msgstr "Bearbeitung übertragen!"
 
-#: mpulsweb/controllers/case_bundle.py:460
+#: mpulsweb/controllers/case_bundle.py:467
 #, python-format
 msgid "%s case was successfully transferred to %s %s"
 msgid_plural "%s cases were successfully transferred to %s %s"
 msgstr[0] "Es wurde %s Fallakte erfolgreich an %s %s übertragen."
 msgstr[1] "Es wurden %s Fallakten erfolgreich an %s %s übertragen."
 
-#: mpulsweb/controllers/case_bundle.py:480
+#: mpulsweb/controllers/case_bundle.py:487
 msgid "Stand-in appointed!"
 msgstr "Vertretung zugewiesen!"
 
-#: mpulsweb/controllers/case_bundle.py:482
+#: mpulsweb/controllers/case_bundle.py:489
 #, python-format
 msgid "%s case was successfully assigned to a substitute."
 msgid_plural "%s cases were successfully assigned to a substitute."
 msgstr[0] "Es wurde für %s Fallakte erfolgreich die Vertretung zugewiesen."
 msgstr[1] "Es wurden für %s Fallakten erfolgreich die Vertretung zugewiesen."
 
-#: mpulsweb/controllers/case_bundle.py:507
+#: mpulsweb/controllers/case_bundle.py:514
 msgid "Export case?"
 msgid_plural "Export cases?"
 msgstr[0] "Fallakte exportieren?"
 msgstr[1] "Fallakten exportieren?"
 
-#: mpulsweb/controllers/case_bundle.py:542 mpulsweb/lib/helpers.py:89
+#: mpulsweb/controllers/case_bundle.py:549 mpulsweb/lib/helpers.py:89
 #: mpulsweb/lib/helpers.py:94 mpulsweb/templates/casemanagement/digest.mako:162
 msgid "unknown"
 msgstr "unbekannt"
 
-#: mpulsweb/controllers/case_bundle.py:546
+#: mpulsweb/controllers/case_bundle.py:553
 #, python-format
 msgid "%d Case was marked for %s"
 msgid_plural "%d Cases were marked for %s"
 msgstr[0] "%d Fallakte wurde für den '%s' markiert."
 msgstr[1] "%d Fallakten wurden für den '%s' markiert."
 
-#: mpulsweb/controllers/case_bundle.py:549
+#: mpulsweb/controllers/case_bundle.py:556
 #, python-format
 msgid ""
 "%d case can be exported. Please click on 'Download' to download the "
@@ -815,7 +815,7 @@
 "Wollen Sie wirklich das Dokument löschen und die Daten unwiederbringlich "
 "verlieren?"
 
-#: mpulsweb/controllers/evaluate.py:255
+#: mpulsweb/controllers/evaluate.py:279
 msgid "Error: Evaluation failed"
 msgstr "Fehler: Auswertung fehlgeschlagen"
 
@@ -1012,24 +1012,40 @@
 
 #: mpulsweb/controllers/privacy.py:30
 msgid "Decline privacy statement not possible"
-msgstr "Zurückziehen der Erklärung nicht möglich"
+msgstr "Die Einwilligungserklärung wurde nicht zurückgezogen!"
 
 #: mpulsweb/controllers/privacy.py:32
 #, python-format
 msgid ""
+"<p>The case is in a non consistent state und it will not be possible to "
+"anonimise it after retracting the privacy statement. The reason for this "
+"is listed below:</p><p>%s</p><p>Please refer to the documentation in case"
+" that the privacy statement has been declined.</p>"
+msgstr ""
+"Das Zurückziehen der Einwilligungserklärung führt zur Anonymisierung der "
+"Akte. Eine Anonymisierung ist für diese Fallakte derzeit aus folgendem "
+"Grund nicht möglich:<p>%s</p><p>Sollte es sich bei dem Fall hingegen um "
+"einen Abbruch handeln, entnehmen Sie bitte der Dokumentation welche "
+"Felder minimal ausgefüllt sein müssen, um einem Abbruch zu dokumentieren "
+"und die Erklärung zurückziehen zu können. Erfüllen Sie die genannten "
+"Anforderungen zur Anonymisierung und wiederholen Sie den Vorgang.</p>"
+
+#: mpulsweb/controllers/privacy.py:34
+#, python-format
+msgid ""
 "The case is in a non consistent state und it will not be possible to "
 "anonimise it after retracting the privacy statement. The reason for this "
-"is listed below:<p>%s</p>"
+"is listed below:%s"
 msgstr ""
-"Die Fallakte ist in einem nicht konsistenten Zustand und kann daher nach "
-"dem Zurückziehen der Erklärung nicht anonymisiert werden. Der Grund "
-"hierfür ist folgend aufgelistet:<p>%s</p>"
+"Das Zurückziehen derEinwilligungserklärung führt zur Anonymisierung der "
+"Akte.Eine Anonymisierung ist für diese Fallakte derzeit auf folgendem "
+"Grund nichtmöglich:<p>%s</p>"
 
-#: mpulsweb/controllers/privacy.py:34
+#: mpulsweb/controllers/privacy.py:36
 msgid "Retract privacy statement?"
 msgstr "Erklärung zurückziehen?"
 
-#: mpulsweb/controllers/privacy.py:35
+#: mpulsweb/controllers/privacy.py:37
 msgid "The case will be anonymised if you retract the privacy statement."
 msgstr ""
 "Die Akte wird anonymisiert, falls die Erklärung zurückgezogen wird. Im "
@@ -1164,51 +1180,49 @@
 msgid ""
 "<p>An anonymisation of this case is not possible: It is only possible to "
 "end cases, which current phase is finished. The phase %s is not finished."
-" Please finish the phase and try to anonymise again.</p><p>Click on OK to"
-" continue.</p>"
+" Please finish the phase and try to anonymise again.</p>"
 msgstr ""
 "<p>Eine Anonymisierung ist für diese Fallakte derzeit nicht möglich: Es "
 "können nur Fälle beendet werden, deren aktuelle Phase beendet wurde. Die "
 "Phase \"%s\" ist derzeit noch nicht beendet. Bitte beenden Sie die Phase "
-"und versuchen Sie erneut eine Anonymisierung.</p><p>Klicken Sie auf "
-"\"OK\", um fortzufahren.</p>"
+"und versuchen Sie erneut eine Anonymisierung.</p>"
 
-#: mpulsweb/model/case.py:1050
+#: mpulsweb/model/case.py:1049
 msgid "Error on fetching data for formletter"
 msgstr "Fehler beim Laden der Daten für Serienbrieffunktion"
 
-#: mpulsweb/model/case.py:1314 mpulsweb/model/case.py:1315
+#: mpulsweb/model/case.py:1313 mpulsweb/model/case.py:1314
 #: mpulsweb/templates/casemanagement/caselist.mako:181
 #: mpulsweb/templates/casemanagement/caselist.mako:182
 #: mpulsweb/templates/search/search.mako:65
 msgid "Editable"
 msgstr "Bearbeitbar"
 
-#: mpulsweb/model/case.py:1316
+#: mpulsweb/model/case.py:1315
 msgid "Outstanding deleted"
 msgstr "Schwebend gelöscht"
 
-#: mpulsweb/model/case.py:1317
+#: mpulsweb/model/case.py:1316
 msgid "Outstanding made anonymous"
 msgstr "Schwebend anonymisiert"
 
-#: mpulsweb/model/case.py:1318
+#: mpulsweb/model/case.py:1317
 msgid "Make anonymous"
 msgstr "Anonymisiert"
 
-#: mpulsweb/model/case.py:1466
+#: mpulsweb/model/case.py:1465
 #, python-format
 msgid "The case with UUID '%s' could not be imported due to rule violations"
 msgstr ""
 "Der Fall mit der UUID '%s' konnte wegen Regelverletzungen nicht "
 "importiert werden."
 
-#: mpulsweb/model/case.py:1496
+#: mpulsweb/model/case.py:1495
 #, python-format
 msgid "The case with UUID '%s' was anonymized already."
 msgstr "Der Fall mit der UUID '%s' wurde bereits anonymisiert."
 
-#: mpulsweb/model/case.py:1499
+#: mpulsweb/model/case.py:1498
 #, python-format
 msgid ""
 "The case with UUID '%s' is either marked for anonymization or marked for "
@@ -1217,7 +1231,7 @@
 "Der Fall mit der UUID '%s' ist entweder schwebend anonymisiert oder "
 "schwebend gelöscht."
 
-#: mpulsweb/model/case.py:1531
+#: mpulsweb/model/case.py:1530
 #, python-format
 msgid "The XML file has the version '%s', but supported is only version '%s'"
 msgstr ""
@@ -1240,7 +1254,7 @@
 msgid "The requested document can't be found."
 msgstr "Das angeforderte Dokument kann nicht gefunden werden."
 
-#: mpulsweb/model/phase.py:208
+#: mpulsweb/model/phase.py:213
 #, python-format
 msgid ""
 "The phase '%s' is in a non consitent                                 "
@@ -1249,29 +1263,29 @@
 "Die Phase '%s' ist nicht in einem konsistenten Zustand und hat nicht "
 "ausgefüllte Pflichtfelder: %s"
 
-#: mpulsweb/model/phase.py:465
+#: mpulsweb/model/phase.py:470
 msgid "Field is OK and requires no further editing"
 msgstr "Dieses Feld ist OK und benötigt keine weitere Bearbeitung"
 
-#: mpulsweb/model/phase.py:468
+#: mpulsweb/model/phase.py:473
 msgid "Field is not OK and requires further editing"
 msgstr "Dieses Feld ist fehlerhaft und benötigt einer weiteren Bearbeitung"
 
-#: mpulsweb/model/user.py:332
+#: mpulsweb/model/user.py:330
 #: mpulsweb/templates/administration/new_user.mako:104
 msgid "role_user"
 msgstr "Bearbeitung"
 
-#: mpulsweb/model/user.py:334 mpulsweb/model/user.py:349
+#: mpulsweb/model/user.py:332 mpulsweb/model/user.py:347
 #: mpulsweb/templates/administration/new_user.mako:106
 msgid "role_admin"
 msgstr "Administration"
 
-#: mpulsweb/model/user.py:336
+#: mpulsweb/model/user.py:334
 msgid "role_ptrole"
 msgstr "PT"
 
-#: mpulsweb/model/user.py:338
+#: mpulsweb/model/user.py:336
 msgid "role_initialadmin"
 msgstr "Super-Administration"
 
@@ -1854,6 +1868,7 @@
 
 #: mpulsweb/templates/administration/overview_user.mako:60
 #: mpulsweb/templates/administration/overview_usergroups.mako:49
+#: mpulsweb/templates/casebundle/standin.mako:52
 #: mpulsweb/templates/casemanagement/caselist.mako:288
 #: mpulsweb/templates/evaluation/agencylist.mako:94
 msgid "No data found."
@@ -2260,7 +2275,7 @@
 msgid "Editor"
 msgstr "Bearbeiter"
 
-#: mpulsweb/templates/casebundle/standin.mako:50
+#: mpulsweb/templates/casebundle/standin.mako:58
 #: mpulsweb/templates/casemanagement/organisation.mako:73
 msgid "Change Standin"
 msgstr "Vertretung ändern"

Modified: base/trunk/mpulsweb/i18n/mpulsweb.pot
===================================================================
--- base/trunk/mpulsweb/i18n/mpulsweb.pot	2011-05-27 08:52:38 UTC (rev 5012)
+++ base/trunk/mpulsweb/i18n/mpulsweb.pot	2011-05-27 10:40:28 UTC (rev 5013)
@@ -8,7 +8,7 @@
 msgstr ""
 "Project-Id-Version: mpulsweb 2.0.0-pre\n"
 "Report-Msgid-Bugs-To: EMAIL at ADDRESS\n"
-"POT-Creation-Date: 2011-05-24 11:05+0200\n"
+"POT-Creation-Date: 2011-05-26 17:04+0200\n"
 "PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\n"
 "Last-Translator: FULL NAME <EMAIL at ADDRESS>\n"
 "Language-Team: LANGUAGE <LL at li.org>\n"
@@ -279,8 +279,8 @@
 "the admininstration. Please click on OK, to get back to the overview."
 msgstr ""
 
-#: mpulsweb/controllers/case.py:57 mpulsweb/controllers/case_bundle.py:290
-#: mpulsweb/controllers/case_bundle.py:321
+#: mpulsweb/controllers/case.py:57 mpulsweb/controllers/case_bundle.py:292
+#: mpulsweb/controllers/case_bundle.py:323
 #: mpulsweb/templates/casemanagement/dialogs/confirm.mako:6
 #: mpulsweb/templates/casemanagement/dialogs/confirm_delete.mako:6
 msgid "Delete case?"
@@ -288,7 +288,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: mpulsweb/controllers/case.py:58
+#: mpulsweb/controllers/case.py:58 mpulsweb/controllers/case_bundle.py:330
 msgid ""
 "Warning! On deleting the case all data will be erased\n"
 "irrecoverable!<br>Only delete the case if this case is <b>not needed for\n"
@@ -319,7 +319,7 @@
 msgid "Click on OK to continue."
 msgstr ""
 
-#: mpulsweb/controllers/case.py:73 mpulsweb/controllers/case_bundle.py:435
+#: mpulsweb/controllers/case.py:73 mpulsweb/controllers/case_bundle.py:442
 #: mpulsweb/templates/casemanagement/dialogs/confirm_restore.mako:6
 msgid "Restore case?"
 msgid_plural "Restore cases?"
@@ -352,19 +352,19 @@
 "Click 'OK' to return to the import dialog."
 msgstr ""
 
-#: mpulsweb/controllers/case.py:218 mpulsweb/model/case.py:1362
-#: mpulsweb/model/phase.py:299 mpulsweb/templates/casemanagement/caselist.mako:152
+#: mpulsweb/controllers/case.py:218 mpulsweb/model/case.py:1361
+#: mpulsweb/model/phase.py:304 mpulsweb/templates/casemanagement/caselist.mako:152
 #: mpulsweb/templates/phase/phase.mako:51
 msgid "Running"
 msgstr ""
 
-#: mpulsweb/controllers/case.py:220 mpulsweb/model/case.py:1364
-#: mpulsweb/model/phase.py:301 mpulsweb/templates/casemanagement/caselist.mako:155
+#: mpulsweb/controllers/case.py:220 mpulsweb/model/case.py:1363
+#: mpulsweb/model/phase.py:306 mpulsweb/templates/casemanagement/caselist.mako:155
 #: mpulsweb/templates/phase/phase.mako:53 mpulsweb/templates/phase/phase.mako:55
 msgid "Finished"
 msgstr ""
 
-#: mpulsweb/controllers/case.py:272 mpulsweb/controllers/case_bundle.py:425
+#: mpulsweb/controllers/case.py:272 mpulsweb/controllers/case_bundle.py:432
 msgid "Case restored!"
 msgid_plural "Cases restored!"
 msgstr[0] ""
@@ -430,13 +430,13 @@
 "in a state from which you can execute the selected action."
 msgstr ""
 
-#: mpulsweb/controllers/case_bundle.py:200
+#: mpulsweb/controllers/case_bundle.py:202
 msgid "Case was marked for evaluation"
 msgid_plural "Cases were marked for evaluation"
 msgstr[0] ""
 msgstr[1] ""
 
-#: mpulsweb/controllers/case_bundle.py:204
+#: mpulsweb/controllers/case_bundle.py:206
 #, python-format
 msgid ""
 "%d case was marked for evaluation. All following evaluations will be limited "
@@ -447,46 +447,46 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: mpulsweb/controllers/case_bundle.py:278
+#: mpulsweb/controllers/case_bundle.py:280
 msgid "Case deleted!"
 msgid_plural "Cases deleted!"
 msgstr[0] ""
 msgstr[1] ""
 
-#: mpulsweb/controllers/case_bundle.py:279
+#: mpulsweb/controllers/case_bundle.py:281
 #, python-format
 msgid "%s case was successfully cleared for deletion."
 msgid_plural "%s cases were successfully cleared for deletion."
 msgstr[0] ""
 msgstr[1] ""
 
-#: mpulsweb/controllers/case_bundle.py:295 mpulsweb/controllers/case_bundle.py:326
+#: mpulsweb/controllers/case_bundle.py:297 mpulsweb/controllers/case_bundle.py:328
 #, python-format
 msgid "Do you really want to delete the following case?%s"
 msgid_plural "Do you really want to delete the following cases?%s"
 msgstr[0] ""
 msgstr[1] ""
 
-#: mpulsweb/controllers/case_bundle.py:309
+#: mpulsweb/controllers/case_bundle.py:311
 msgid "Case successfully deleted."
 msgid_plural "Cases successfully deleted."
 msgstr[0] ""
 msgstr[1] ""
 
-#: mpulsweb/controllers/case_bundle.py:312
+#: mpulsweb/controllers/case_bundle.py:314
 #, python-format
 msgid "%s case was successfully deleted."
 msgid_plural "%s cases were successfully deleted."
 msgstr[0] ""
 msgstr[1] ""
 
-#: mpulsweb/controllers/case_bundle.py:341
+#: mpulsweb/controllers/case_bundle.py:348
 msgid "Case successfully cleared for anonymisation!"
 msgid_plural "Cases successfully cleared for anonymisation!"
 msgstr[0] ""
 msgstr[1] ""
 
-#: mpulsweb/controllers/case_bundle.py:347
+#: mpulsweb/controllers/case_bundle.py:354
 #, python-format
 msgid ""
 "%s case was cleared for anonymisation. It will be presented to the "
@@ -497,13 +497,13 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: mpulsweb/controllers/case_bundle.py:360
+#: mpulsweb/controllers/case_bundle.py:367
 msgid "Clear case for anonymisation?"
 msgid_plural "Clear cases for anonymisation?"
 msgstr[0] ""
 msgstr[1] ""
 
-#: mpulsweb/controllers/case_bundle.py:372
+#: mpulsweb/controllers/case_bundle.py:379
 #, python-format
 msgid ""
 "Do you really want to clear the following case for anonymisation? The case "
@@ -516,26 +516,26 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: mpulsweb/controllers/case_bundle.py:386
+#: mpulsweb/controllers/case_bundle.py:393
 msgid "Case anonymised!"
 msgid_plural "Cases anonymised!"
 msgstr[0] ""
 msgstr[1] ""
 
-#: mpulsweb/controllers/case_bundle.py:389
+#: mpulsweb/controllers/case_bundle.py:396
 #, python-format
 msgid "%s case was successfully anonymised."
 msgid_plural "%s cases were successfully anonymised."
 msgstr[0] ""
 msgstr[1] ""
 
-#: mpulsweb/controllers/case_bundle.py:398
+#: mpulsweb/controllers/case_bundle.py:405
 msgid "Anonymise case?"
 msgid_plural "Anonymise cases?"
 msgstr[0] ""
 msgstr[1] ""
 
-#: mpulsweb/controllers/case_bundle.py:410
+#: mpulsweb/controllers/case_bundle.py:417
 #, python-format
 msgid ""
 "Do you really want to anonymise the case and irrevocably lose its personal "
@@ -548,14 +548,14 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: mpulsweb/controllers/case_bundle.py:427
+#: mpulsweb/controllers/case_bundle.py:434
 #, python-format
 msgid "%s was successfully restored."
 msgid_plural "%s were successfully restored."
 msgstr[0] ""
 msgstr[1] ""
 
-#: mpulsweb/controllers/case_bundle.py:441
+#: mpulsweb/controllers/case_bundle.py:448
 #, python-format
 msgid ""
 "Do you really want to restore the following case? It will be available again "
@@ -566,47 +566,47 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: mpulsweb/controllers/case_bundle.py:458
+#: mpulsweb/controllers/case_bundle.py:465
 msgid "Editor appointed!"
 msgstr ""
 
-#: mpulsweb/controllers/case_bundle.py:460
+#: mpulsweb/controllers/case_bundle.py:467
 #, python-format
 msgid "%s case was successfully transferred to %s %s"
 msgid_plural "%s cases were successfully transferred to %s %s"
 msgstr[0] ""
 msgstr[1] ""
 
-#: mpulsweb/controllers/case_bundle.py:480
+#: mpulsweb/controllers/case_bundle.py:487
 msgid "Stand-in appointed!"
 msgstr ""
 
-#: mpulsweb/controllers/case_bundle.py:482
+#: mpulsweb/controllers/case_bundle.py:489
 #, python-format
 msgid "%s case was successfully assigned to a substitute."
 msgid_plural "%s cases were successfully assigned to a substitute."
 msgstr[0] ""
 msgstr[1] ""
 
-#: mpulsweb/controllers/case_bundle.py:507
+#: mpulsweb/controllers/case_bundle.py:514
 msgid "Export case?"
 msgid_plural "Export cases?"
 msgstr[0] ""
 msgstr[1] ""
 
-#: mpulsweb/controllers/case_bundle.py:542 mpulsweb/lib/helpers.py:89
+#: mpulsweb/controllers/case_bundle.py:549 mpulsweb/lib/helpers.py:89
 #: mpulsweb/lib/helpers.py:94 mpulsweb/templates/casemanagement/digest.mako:162
 msgid "unknown"
 msgstr ""
 
-#: mpulsweb/controllers/case_bundle.py:546
+#: mpulsweb/controllers/case_bundle.py:553
 #, python-format
 msgid "%d Case was marked for %s"
 msgid_plural "%d Cases were marked for %s"
 msgstr[0] ""
 msgstr[1] ""
 
-#: mpulsweb/controllers/case_bundle.py:549
+#: mpulsweb/controllers/case_bundle.py:556
 #, python-format
 msgid ""
 "%d case can be exported. Please click on 'Download' to download the exported "
@@ -671,7 +671,7 @@
 msgid "Do you want to delete the document and irrevocably lose the data?"
 msgstr ""
 
-#: mpulsweb/controllers/evaluate.py:255
+#: mpulsweb/controllers/evaluate.py:279
 msgid "Error: Evaluation failed"
 msgstr ""
 
@@ -841,16 +841,25 @@
 #: mpulsweb/controllers/privacy.py:32
 #, python-format
 msgid ""
+"<p>The case is in a non consistent state und it will not be possible to "
+"anonimise it after retracting the privacy statement. The reason for this is "
+"listed below:</p><p>%s</p><p>Please refer to the documentation in case that "
+"the privacy statement has been declined.</p>"
+msgstr ""
+
+#: mpulsweb/controllers/privacy.py:34
+#, python-format
+msgid ""
 "The case is in a non consistent state und it will not be possible to "
 "anonimise it after retracting the privacy statement. The reason for this is "
-"listed below:<p>%s</p>"
+"listed below:%s"
 msgstr ""
 
-#: mpulsweb/controllers/privacy.py:34
+#: mpulsweb/controllers/privacy.py:36
 msgid "Retract privacy statement?"
 msgstr ""
 
-#: mpulsweb/controllers/privacy.py:35
+#: mpulsweb/controllers/privacy.py:37
 msgid "The case will be anonymised if you retract the privacy statement."
 msgstr ""
 
@@ -971,51 +980,50 @@
 msgid ""
 "<p>An anonymisation of this case is not possible: It is only possible to end "
 "cases, which current phase is finished. The phase %s is not finished. Please "
-"finish the phase and try to anonymise again.</p><p>Click on OK to "
-"continue.</p>"
+"finish the phase and try to anonymise again.</p>"
 msgstr ""
 
-#: mpulsweb/model/case.py:1050
+#: mpulsweb/model/case.py:1049
 msgid "Error on fetching data for formletter"
 msgstr ""
 
-#: mpulsweb/model/case.py:1314 mpulsweb/model/case.py:1315
+#: mpulsweb/model/case.py:1313 mpulsweb/model/case.py:1314
 #: mpulsweb/templates/casemanagement/caselist.mako:181
 #: mpulsweb/templates/casemanagement/caselist.mako:182
 #: mpulsweb/templates/search/search.mako:65
 msgid "Editable"
 msgstr ""
 
-#: mpulsweb/model/case.py:1316
+#: mpulsweb/model/case.py:1315
 msgid "Outstanding deleted"
 msgstr ""
 
-#: mpulsweb/model/case.py:1317
+#: mpulsweb/model/case.py:1316
 msgid "Outstanding made anonymous"
 msgstr ""
 
-#: mpulsweb/model/case.py:1318
+#: mpulsweb/model/case.py:1317
 msgid "Make anonymous"
 msgstr ""
 
-#: mpulsweb/model/case.py:1466
+#: mpulsweb/model/case.py:1465
 #, python-format
 msgid "The case with UUID '%s' could not be imported due to rule violations"
 msgstr ""
 
-#: mpulsweb/model/case.py:1496
+#: mpulsweb/model/case.py:1495
 #, python-format
 msgid "The case with UUID '%s' was anonymized already."
 msgstr ""
 
-#: mpulsweb/model/case.py:1499
+#: mpulsweb/model/case.py:1498
 #, python-format
 msgid ""
 "The case with UUID '%s' is either marked for anonymization or marked for "
 "deletion."
 msgstr ""
 
-#: mpulsweb/model/case.py:1531
+#: mpulsweb/model/case.py:1530
 #, python-format
 msgid "The XML file has the version '%s', but supported is only version '%s'"
 msgstr ""
@@ -1036,35 +1044,35 @@
 msgid "The requested document can't be found."
 msgstr ""
 
-#: mpulsweb/model/phase.py:208
+#: mpulsweb/model/phase.py:213
 #, python-format
 msgid ""
 "The phase '%s' is in a non consitent                                 state "
 "and has missing required fields: %s"
 msgstr ""
 
-#: mpulsweb/model/phase.py:465
+#: mpulsweb/model/phase.py:470
 msgid "Field is OK and requires no further editing"
 msgstr ""
 
-#: mpulsweb/model/phase.py:468
+#: mpulsweb/model/phase.py:473
 msgid "Field is not OK and requires further editing"
 msgstr ""
 
-#: mpulsweb/model/user.py:332 mpulsweb/templates/administration/new_user.mako:104
+#: mpulsweb/model/user.py:330 mpulsweb/templates/administration/new_user.mako:104
 msgid "role_user"
 msgstr ""
 
-#: mpulsweb/model/user.py:334 mpulsweb/model/user.py:349
+#: mpulsweb/model/user.py:332 mpulsweb/model/user.py:347
 #: mpulsweb/templates/administration/new_user.mako:106
 msgid "role_admin"
 msgstr ""
 
-#: mpulsweb/model/user.py:336
+#: mpulsweb/model/user.py:334
 msgid "role_ptrole"
 msgstr ""
 
-#: mpulsweb/model/user.py:338
+#: mpulsweb/model/user.py:336
 msgid "role_initialadmin"
 msgstr ""
 
@@ -1635,6 +1643,7 @@
 
 #: mpulsweb/templates/administration/overview_user.mako:60
 #: mpulsweb/templates/administration/overview_usergroups.mako:49
+#: mpulsweb/templates/casebundle/standin.mako:52
 #: mpulsweb/templates/casemanagement/caselist.mako:288
 #: mpulsweb/templates/evaluation/agencylist.mako:94
 msgid "No data found."
@@ -2035,7 +2044,7 @@
 msgid "Editor"
 msgstr ""
 
-#: mpulsweb/templates/casebundle/standin.mako:50
+#: mpulsweb/templates/casebundle/standin.mako:58
 #: mpulsweb/templates/casemanagement/organisation.mako:73
 msgid "Change Standin"
 msgstr ""

Modified: base/trunk/mpulsweb/model/case.py
===================================================================
--- base/trunk/mpulsweb/model/phase.py	2011-05-27 08:52:38 UTC (rev 5012)
+++ base/trunk/mpulsweb/model/phase.py	2011-05-27 10:40:28 UTC (rev 5013)
@@ -62,7 +62,12 @@
     def __init__(self, value):
         self.value = value
 
+class PhaseAnonymizableCheckException(ConsistenceCheckException):
 
+    def __init__(self, value):
+        self.value = value
+
+
 class PhaseFactory:
 
     def __init__(self):



More information about the Mpuls-commits mailing list
--- base/trunk/mpulsweb/model/case.py	2011-05-27 08:52:38 UTC (rev 5012)
+++ base/trunk/mpulsweb/model/case.py	2011-05-27 10:40:28 UTC (rev 5013)
@@ -58,7 +58,7 @@
 from mpulsweb.model.document import listDocuments
 from mpulsweb.model.statement import PrivacyStatement
 from mpulsweb.model.phase import PhaseFactory, StartPhasePart, \
-    ConsistenceCheckException, PHASEFIELD, PC_MANUAL
+    PhaseAnonymizableCheckException, ConsistenceCheckException, PHASEFIELD, PC_MANUAL
 from mpulsweb.model.user import UserObject
 from mpulsweb.model.agencysettings import Agency
 from mpulsweb.model.logbook import export_logbook, get_logbook_import_factory, \
@@ -735,8 +735,8 @@
         self.get_phaseslist().check_consistence(fields, phase)
 
     def check_anonymizeability(self, fields=None, phase=None):
-        """Raises ConsistenceCheckException if the case is not in a
-        anonymizable state.
+        """Raises PhaseAnonymizableCheckException or ConsistenceCheckException
+        if the case is not in a anonymizable state.
         """
 
         # 1. Check if anonymisation is allowed in the current phase
@@ -749,7 +749,7 @@
         desc = g.mpuls_config.get('phases',
                                   'description')[0].get(phasepart.phase)
         if not phasepart.is_anonymizable():
-            raise ConsistenceCheckException(h.literal(_( \
+            raise PhaseAnonymizableCheckException(h.literal(_( \
             u"<p>An anonymisation of the case is not possible in phase %s." \
             u"</p><p>Please remove this case.</p>") % desc))
 
@@ -778,8 +778,7 @@
                     "<p>An anonymisation of this case is not possible: " \
                     "It is only possible to end cases, which current phase" \
                     " is finished. The phase %s is not finished. Please " \
-                    "finish the phase and try to anonymise again.</p>" \
-                    "<p>Click on OK to continue.</p>") % desc))
+                    "finish the phase and try to anonymise again.</p>") % desc))
 
     def make_consistent(self, endphase=None):
         """Will ensure that the case is in a (minimal) consistent state. That

Modified: base/trunk/mpulsweb/model/phase.py
===================================================================